<?php

namespace BancaCore\WpWidgets;

use WP_Query;
use WP_Widget;

/**
 * Widget API: WP_Widget_Recent_Posts class
 *
 * @package WordPress
 * @subpackage Widgets
 * @since 4.4.0
 */

/**
 * Core class used to implement a Recent Posts widget.
 *
 * @since 2.8.0
 *
 * @see WP_Widget
 */
class Widget_Recent_Posts extends WP_Widget
{

    /**
     * Sets up a new Recent Posts widget instance.
     *
     * @since 2.8.0
     */
    public function __construct()
    {
        $widget_ops = array(
            'classname' => 'recent_news_widget',
            'description' => esc_html__('Your site&#8217;s most recent Posts.', 'banca-core'),
            'customize_selective_refresh' => true,
        );
        parent::__construct('banca_recent-posts', esc_html__('Recent Posts (Theme)', 'banca'), $widget_ops);
        $this->alt_option_name = 'widget_recent_entries';
    }

    /**
     * Outputs the content for the current Recent Posts widget instance.
     *
     * @param array $args Display arguments including 'before_title', 'after_title',
     *                        'before_widget', and 'after_widget'.
     * @param array $instance Settings for the current Recent Posts widget instance.
     * @since 2.8.0
     *
     */
    public function widget($args, $instance)
    {
        if (!isset($args['widget_id'])) {
            $args['widget_id'] = $this->id;
        }

        $title = (!empty($instance['title'])) ? $instance['title'] : esc_html__('Recent Posts', 'banca');

        /** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
        $title = apply_filters('widget_title', $title, $instance, $this->id_base);

        $number = (!empty($instance['number'])) ? absint($instance['number']) : 5;
        if (!$number) {
            $number = 5;
        }

        $show_date = isset($instance['show_date']) ? $instance['show_date'] : false;

        /**
         * Filters the arguments for the Recent Posts widget.
         *
         * @param array $args An array of arguments used to retrieve the recent posts.
         * @param array $instance Array of settings for the current widget.
         * @see WP_Query::get_posts()
         *
         * @since 3.4.0
         * @since 4.9.0 Added the `$instance` parameter.
         *
         */
        $r = new WP_Query(apply_filters('widget_posts_args', array(
            'posts_per_page' => $number,
            'no_found_rows' => true,
            'post_status' => 'publish',
            'ignore_sticky_posts' => true,
        ), $instance));

        if (!$r->have_posts()) {
            return;
        }

        echo $args['before_widget'];

        if ($title) {
            echo $args['before_title'] . $title . $args['after_title'];
        }

        foreach ($r->posts as $recent_post) {
            $post_title = get_the_title($recent_post->ID);
            $title = (!empty($post_title)) ? $post_title : esc_html__('(no title)', 'banca');
            $title_length = function_exists('get_field') ? get_field('title_length', 'widget_' . $args['widget_id']) : 24;
            if (!isset($title_length)) {
                $title_length = 40;
            }
            if (has_post_thumbnail($recent_post->ID)) {
                ?>
                <div <?php post_class('media recent_post_item') ?>>
                    <a href="<?php the_permalink($recent_post->ID); ?>">
                        <?php echo get_the_post_thumbnail($recent_post->ID, 'banca_70x70', array('class' => 'media-object')); ?>
                    </a>
                    <div class="media-body">
                        <a href="<?php the_permalink($recent_post->ID); ?>" title="<?php echo esc_attr($title); ?>">
                            <h5> <?php banca_core_limit_latter($title, $title_length, ''); ?> </h5>
                        </a>
                        <?php if ($show_date) : ?>
                            <a class="entry_post_date" href="<?php banca_core_day_link() ?>">
                                <i class="far fa-calendar-alt"></i>
                                <?php echo get_the_date(get_option('date_format'), $recent_post->ID); ?>
                            </a>
                        <?php endif; ?>
                    </div>
                </div>
                <?php
            }
        }

        echo $args['after_widget'];
    }

    /**
     * Outputs the settings form for the Recent Posts widget.
     *
     * @param array $instance Current settings.
     * @since 2.8.0
     *
     */
    public function form($instance)
    {
        $title = isset($instance['title']) ? esc_attr($instance['title']) : '';
        $number = isset($instance['number']) ? absint($instance['number']) : 5;
        $length = isset($instance['length']) ? absint($instance['length']) : 24;
        $show_date = isset($instance['show_date']) ? (bool)$instance['show_date'] : true;
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title:', 'banca'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>"
                   name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text"
                   value="<?php echo esc_attr($title); ?>"/></p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('number')); ?>"><?php esc_html_e('Number of Posts to Show:', 'banca'); ?></label>
            <input class="tiny-text" id="<?php echo esc_attr($this->get_field_id('number')); ?>"
                   name="<?php echo esc_attr($this->get_field_name('number')); ?>" type="number" step="1" min="1"
                   value="<?php echo esc_attr($number); ?>" size="4"/></p>

        <p><input class="checkbox" type="checkbox"<?php esc_attr(checked($show_date)); ?>
                  id="<?php echo esc_attr($this->get_field_id('show_date')); ?>"
                  name="<?php echo esc_attr($this->get_field_name('show_date')); ?>"/>
            <label for="<?php echo esc_attr($this->get_field_id('show_date')); ?>"><?php esc_html_e('Display Post Date?', 'banca'); ?></label>
        </p>
        <?php
    }

    /**
     * Handles updating the settings for the current Recent Posts widget instance.
     *
     * @param array $new_instance New settings for this instance as input by the user via
     *                            WP_Widget::form().
     * @param array $old_instance Old settings for this instance.
     * @return array Updated settings to save.
     * @since 2.8.0
     *
     */
    public function update($new_instance, $old_instance)
    {
        $instance = $old_instance;
        $instance['title'] = sanitize_text_field($new_instance['title']);
        $instance['number'] = (int)$new_instance['number'];
        $instance['show_date'] = isset($new_instance['show_date']) ? (bool)$new_instance['show_date'] : false;
        return $instance;
    }
}