<?php
namespace BancaCore\WpWidgets;
use WP_Widget;
use WP_Query;

/**
 * Widget API: Banca_Widget_Categories class
 *
 * @package WordPress
 * @subpackage Widgets
 * @since 4.4.0
 */

/**
 * Core class used to implement a Categories widget.
 *
 * @since 2.8.0
 *
 * @see WP_Widget
 */
class Widget_Categories extends WP_Widget {

    /**
     * Sets up a new Categories widget instance.
     *
     * @since 2.8.0
     */
    public function __construct() {
        $widget_ops = array(
            'classname'                   => 'widget-subscribe',
            'description'                 => __( 'A list or dropdown of categories.' ),
            'customize_selective_refresh' => true,
        );
        parent::__construct( 'banca_widgets_subscribe', esc_html__( 'Subscribe (Theme)', 'banca-core' ), $widget_ops );

    }

    /**
     * Outputs the content for the current Categories' widget instance.
     *
     * @since 2.8.0
     * @since 4.2.0 Creates a unique HTML ID for the `<select>` element
     *              if more than one instance is displayed on the page.
     *
     * @param array $args     Display arguments including 'before_title', 'after_title',
     *                        'before_widget', and 'after_widget'.
     * @param array $instance Settings for the current Categories' widget instance.
     */
    public function widget( $args, $instance ) {

        $title         = ! empty( $instance['title'] ) ? $instance['title'] : '';
        $subtitle      = ! empty( $instance['subtitle'] ) ? $instance['subtitle'] : '';
        $action_btn    = ! empty( $instance['action_btn'] ) ? $instance['action_btn'] : '';
        $email_placeholder    = ! empty( $instance['email_placeholder'] ) ? $instance['email_placeholder'] : '';

        echo $args['before_widget'];

        ?>
        <div class="widget-subscribe">
            <h4 class="widget-title mb-15"><?php echo esc_html($title) ?></h4>
            <p><?php echo esc_html($subtitle) ?></p>
            <form action="#" class="mt-15">
                <input class="form-control" type="text" placeholder="<?php echo esc_attr($email_placeholder) ?>">
                <button class="theme-btn w-100 mt-30" type="submit"><?php echo esc_html($action_btn) ?></button>
            </form>
        </div>
        <?php

        echo $args['after_widget'];
    }

    /**
     * Handles updating settings for the current Categories widget instance.
     *
     * @since 2.8.0
     *
     * @param array $new_instance New settings for this instance as input by the user via
     *                            WP_Widget::form().
     * @param array $old_instance Old settings for this instance.
     * @return array Updated settings to save.
     */
    public function update( $new_instance, $old_instance ) {
        $instance                 = $old_instance;
        $instance['title']        = sanitize_text_field( $new_instance['title'] );
        $instance['subtitle']        = ! empty( $new_instance['count'] ) ? 1 : 0;
        $instance['action_btn'] = ! empty( $new_instance['hierarchical'] ) ? 1 : 0;
        $instance['email_placeholder']     = ! empty( $new_instance['dropdown'] ) ? 1 : 0;
        return $instance;
    }

    /**
     * Outputs the settings form for the Categories widget.
     *
     * @since 2.8.0
     *
     * @param array $instance Current settings.
     */
    public function form( $instance ) {

        // Defaults.
        $instance     = wp_parse_args( (array) $instance, array( 'title' => '' ) );
        $count        = isset( $instance['count'] ) ? (bool) $instance['count'] : false;
        $hierarchical = isset( $instance['hierarchical'] ) ? (bool) $instance['hierarchical'] : false;
        $dropdown     = isset( $instance['dropdown'] ) ? (bool) $instance['dropdown'] : false;
        $number       = isset( $instance['cats_num_banca'] ) ? $instance['cats_num_banca'] : 5;
        ?>
        <p>
            <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $instance['title'] ); ?>" />
        </p>

        <p>
            <label for="<?php echo $this->get_field_id( 'cats_num_banca' ); ?>"><?php _e( 'Number of Category to show:' ); ?></label>
            <input class="tiny-text" id="<?php echo $this->get_field_id( 'cats_num_banca' ); ?>" name="<?php echo $this->get_field_name( 'cats_num_banca' ); ?>" type="number" step="1" min="1" value="<?php echo esc_attr($number); ?>" />
        </p>

        <p>
            <input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id( 'dropdown' ); ?>" name="<?php echo $this->get_field_name( 'dropdown' ); ?>"<?php checked( $dropdown ); ?> />
            <label for="<?php echo $this->get_field_id( 'dropdown' ); ?>"><?php _e( 'Display as dropdown' ); ?></label>
            <br />

            <input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id( 'count' ); ?>" name="<?php echo $this->get_field_name( 'count' ); ?>"<?php checked( $count ); ?> />
            <label for="<?php echo $this->get_field_id( 'count' ); ?>"><?php _e( 'Show post counts' ); ?></label>
            <br />

            <input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id( 'hierarchical' ); ?>" name="<?php echo $this->get_field_name( 'hierarchical' ); ?>"<?php checked( $hierarchical ); ?> />
            <label for="<?php echo $this->get_field_id( 'hierarchical' ); ?>"><?php _e( 'Show hierarchy' ); ?></label>
        </p>
        <?php
    }

}